<?php

/**
 * @file
 * Provides Memsource translation plugin controller.
 */

/**
 * Memsource translation plugin controller.
 */
class TMGMTmemsourcePluginController extends TMGMTDefaultTranslatorPluginController {

  /**
   * Implements TMGMTTranslatorPluginControllerInterface::getSupportedRemoteLanguages().
   */
  public function getSupportedRemoteLanguages(TMGMTTranslator $translator) {
    return $this->getConnector($translator)->getSupportedRemoteLanguages();
  }

  /**
   * Implements TMGMTTranslatorPluginControllerInterface::isAvailable().
   */
  public function isAvailable(TMGMTTranslator $translator) {
    return !empty($translator->getSetting('memsource_user_name')) &&
      !empty($translator->getSetting('memsource_password'));
  }

  /**
   * Implements TMGMTTranslatorPluginControllerInterface::requestTranslation().
   *
   * Here we will actually query source and get translations.
   */
  public function requestTranslation(TMGMTJob $job) {
    $job = $this->getConnector($job->getTranslator())->requestJobItemsTranslation($job->getItems());
    if (!$job->isRejected()) {
      $job->submitted();
    }
  }

  /**
   * {@inheritdoc}
   */
  public function defaultSettings() {
    $defaults = parent::defaultSettings();
    // Enable CDATA for content encoding in File translator.
    $defaults['xliff_cdata'] = TRUE;
    return $defaults;
  }

  /**
   * Gets memsource service connector.
   *
   * @param TMGMTTranslator $translator
   *   Current job translator.
   *
   * @return MemsourceConnector
   *   Memsource connector instance.
   */
  public function getConnector(TMGMTTranslator $translator) {
    return new MemsourceConnector(
      $translator->getSetting('service_url'),
      $translator->getSetting('memsource_user_name'),
      $translator->getSetting('memsource_password'),
      $translator
    );
  }

}
