<?php

/**
 * @file
 * Please supply a file description.
 */

/**
 * @file
 * Provides Memsource translation plugin controller.
 */
class TMGMTMemsourceTranslatorUIController extends TMGMTDefaultTranslatorUIController {

  /**
   * Overrides TMGMTDefaultTranslatorUIController::pluginSettingsForm().
   */
  public function pluginSettingsForm($form, &$form_state, TMGMTTranslator $translator, $busy = FALSE) {
    $form['service_url'] = array(
      '#type' => 'textfield',
      '#title' => t('Memsource API endpoint'),
      '#default_value' => $translator->getSetting('service_url') ?: 'https://cloud.memsource.com/web/api',
      '#description' => t('Please enter the Memsource API endpoint.'),
      '#required' => TRUE,
      '#placeholder' => 'https://cloud.memsource.com/web/api',
    );
    $form['memsource_user_name'] = [
      '#type' => 'textfield',
      '#title' => t('User name'),
      '#default_value' => $translator->getSetting('memsource_user_name'),
      '#description' => t('Please enter your Memsource Cloud user name.'),
      '#required' => TRUE,
      '#placeholder' => t('Please enter your Memsource Cloud user name.'),
    ];
    $form['memsource_password'] = [
      '#type' => 'password',
      '#title' => t('Password'),
      '#default_value' => $translator->getSetting('memsource_password'),
      '#description' => t('Please enter your Memsource Cloud password.'),
      '#required' => TRUE,
      '#placeholder' => t('Please enter your Memsource Cloud password.'),
    ];
    return parent::pluginSettingsForm($form, $form_state, $translator, $busy);
  }

  /**
   * Implements TMGMTTranslatorUIControllerInterface::checkoutInfo().
   */
  public function checkoutInfo(TMGMTJob $job) {
    $form = array();

    if ($job->isActive()) {
      $form['actions']['pull'] = array(
        '#type' => 'submit',
        '#value' => t('Pull translations'),
        '#submit' => array('_tmgmt_memsource_pull_submit'),
        '#weight' => -10,
      );
    }

    return $form;
  }

  /**
   * Overrides TMGMTDefaultTranslatorUIController::checkoutSettingsForm().
   */
  public function checkoutSettingsForm($form, &$form_state, TMGMTJob $job) {
    /**
     * @var TMGMTMemsourcePluginController $controller The translator object.
     */
    $controller = $job->getTranslator()->getController();
    $templates_json = $controller->getConnector($job->getTranslator())->sendApiRequest('v2/projectTemplate/list');
    $remote_languages_mappings = $job->getTranslator()->settings['remote_languages_mappings'];
    $sourceLang = isset($remote_languages_mappings[$job->source_language]) ? $remote_languages_mappings[$job->source_language] : $job->source_language;
    $targetLang = isset($remote_languages_mappings[$job->target_language]) ? $remote_languages_mappings[$job->target_language] : $job->target_language;
    $templates = [0 => '-'];
    foreach ($templates_json as $template) {
      // Display only templates which match the selected source AND (match the selected target lang OR target lang is empty)
      if($template['sourceLang'] == $sourceLang && (in_array($targetLang, $template['targetLangs']) || $template['targetLangs'] == null)) {
        $templates[$template['id']] = $template['templateName'];
      }
    }
    $settings['project_name'] = [
      '#type' => 'textfield',
      '#title' => t('Project name'),
      '#default_value' => NULL,
      '#description' => t('Enter the name of your Memsource Cloud project.'),
    ];
    $settings['project_template'] = [
      '#type' => 'select',
      '#title' => t('Project template'),
      '#options' => $templates,
      '#description' => t('Select a  Memsource Cloud project template.'),
    ];
    $settings['due_date'] = [
      '#type' => 'date',
      '#title' => t('Due Date'),
      '#date_date_format' => 'Y-m-d',
      '#description' => t('Enter the due date of this translation.'),
      '#default_value' => NULL,
    ];

    return $settings;
  }

}
